import { Body, Controller, Post, Response } from '@nestjs/common';
import { IUserLoginRequest } from 'src/dto/user.dto';
import { IUser } from 'src/entity/user.entity';
import { AuthService } from 'src/service/auth.service';
import { SECURE_SIGN, TOKEN } from 'src/config/constant';
import { RedisService } from 'src/service/redis.service';
import { EncryptUtil } from '@backset/util';

@Controller('auth')
export class AuthController {
  constructor(
    private readonly authService: AuthService,
    private readonly redisService: RedisService,
  ) {}

  /**
   * 前台用户登录
   */
  @Post('/user/login')
  async userLogin(@Body() param: IUserLoginRequest, @Response() res) {
    try {
      const user: IUser = await this.authService.userLogin(param);
      const { user_pass, ...rest } = user;
      const token = EncryptUtil.createToken(rest);
      const key = this.authService.getRedisKey(user);
      this.redisService.set(key, token);
      res.cookie(SECURE_SIGN, token, {
        expires: TOKEN.EXPIRES,
        sameSite: 'strict',
        httpOnly: true,
      });
      if (user) return res.send(rest);
    } catch (error) {
      console.log(error);
    }
  }

  /**
   * 管理系统登录
   */
  @Post('/admin/login')
  async adminLogin() {}
}
